@@ -1,7 +1,7 @@
 // qtractorDssiPlugin.cpp
 //
 /****************************************************************************
-   Copyright (C) 2005-2021, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2022, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -952,7 +952,7 @@ qtractorDssiPlugin::qtractorDssiPlugin ( qtractorPluginList *pList,
 qtractorDssiPlugin::~qtractorDssiPlugin (void)
 {
 	// Cleanup all plugin instances...
-	setChannels(0);
+	cleanup();	// setChannels(0);
 
 	// Remove reference from multiple instance pool.
 	if (m_pDssiMulti)
