@@ -70,8 +70,11 @@ qtractorMidiControlObserver::qtractorMidiControlObserver (
 qtractorMidiControlObserver::~qtractorMidiControlObserver (void)
 {
 	qtractorMidiControl *pMidiControl = qtractorMidiControl::getInstance();
-	if (pMidiControl && pMidiControl->isMidiObserverMapped(this))
-		pMidiControl->unmapMidiObserver(this);
+	if (pMidiControl) {
+		pMidiControl->unmapMidiObserverWidgets(this);
+		if (pMidiControl->isMidiObserverMapped(this))
+			pMidiControl->unmapMidiObserver(this);
+	}
 }
 
 
@@ -79,7 +82,6 @@ qtractorMidiControlObserver::~qtractorMidiControlObserver (void)
 unsigned short qtractorMidiControlObserver::midiScale (void) const
 {
 	if (m_ctype == qtractorMidiEvent::PITCHBEND ||
-
 		m_ctype == qtractorMidiEvent::CONTROL14 ||
 		m_ctype == qtractorMidiEvent::REGPARAM  ||
 		m_ctype == qtractorMidiEvent::NONREGPARAM)
