@@ -83,7 +83,7 @@ qtractorPluginFactory *qtractorPluginFactory::getInstance (void)
 
 // Contructor.
 qtractorPluginFactory::qtractorPluginFactory ( QObject *pParent )
-	: QObject(pParent), m_typeHint(qtractorPluginType::Any)
+	: QObject(pParent), m_typeHint(qtractorPluginType::Any), m_bRescan(false)
 {
 	// Register cache file paths...
 	//m_clearFilePaths.clear();
@@ -482,11 +482,11 @@ bool qtractorPluginFactory::writeBlacklist (
 
 
 // Generic plugin-scan factory method.
-bool qtractorPluginFactory::startScan ( qtractorPluginType::Hint typeHint )
+int qtractorPluginFactory::startScan ( qtractorPluginType::Hint typeHint )
 {
 	qtractorOptions *pOptions = qtractorOptions::getInstance();
 	if (pOptions == nullptr)
-		return false;
+		return 0;
 
 	int iDummyPluginHash = 0;
 
@@ -515,14 +515,27 @@ bool qtractorPluginFactory::startScan ( qtractorPluginType::Hint typeHint )
 
 	const QString& sCacheFilePath = m_cacheFilePaths.value(typeHint);
 	if (sCacheFilePath.isEmpty())
-		return false;
+		return 0;
 
 	Scanner *pScanner = new Scanner(typeHint, this);
 	if (!pScanner->open(sCacheFilePath, iDummyPluginHash))
-		return false;
+		return 0;
 
 	m_scanners.insert(typeHint, pScanner);
-	return true;
+
+	QStringList& files = m_files[typeHint];
+	files.append(pScanner->files());
+#ifdef CONFIG_LV2
+	if (typeHint == qtractorPluginType::Lv2)
+		files.clear();
+#endif
+	int iFileCount = files.count();
+	if (m_bRescan || iFileCount == 0) {
+		m_bRescan = false;
+		iFileCount += addFiles(typeHint, pluginPaths(typeHint));
+	}
+
+	return iFileCount;
 }
 
 
@@ -532,9 +545,6 @@ void qtractorPluginFactory::scan (void)
 	// Start clean.
 	reset();
 
-	if (pluginPaths(m_typeHint).isEmpty()) // Just in case...
-		updatePluginPaths(m_typeHint);
-
 	// Get paths based on hints...
 	int iFileCount = 0;
 
@@ -542,77 +552,42 @@ void qtractorPluginFactory::scan (void)
 	// LADSPA default path...
 	if (m_typeHint == qtractorPluginType::Any ||
 		m_typeHint == qtractorPluginType::Ladspa) {
-		const qtractorPluginType::Hint typeHint
-			= qtractorPluginType::Ladspa;
-		const QStringList& paths = m_paths.value(typeHint);
-		if (!paths.isEmpty()) {
-			iFileCount += addFiles(typeHint, paths);
-			startScan(typeHint);
-		}
+		iFileCount += startScan(qtractorPluginType::Ladspa);
 	}
 #endif
 #ifdef CONFIG_DSSI
 	// DSSI default path...
 	if (m_typeHint == qtractorPluginType::Any ||
 		m_typeHint == qtractorPluginType::Dssi) {
-		const qtractorPluginType::Hint typeHint
-			= qtractorPluginType::Dssi;
-		const QStringList& paths = m_paths.value(typeHint);
-		if (!paths.isEmpty()) {
-			iFileCount += addFiles(typeHint, paths);
-			startScan(typeHint);
-		}
+		iFileCount += startScan(qtractorPluginType::Dssi);
 	}
 #endif
 #ifdef CONFIG_VST2
 	// VST default path...
 	if (m_typeHint == qtractorPluginType::Any ||
 		m_typeHint == qtractorPluginType::Vst2) {
-		const qtractorPluginType::Hint typeHint
-			= qtractorPluginType::Vst2;
-		const QStringList& paths = m_paths.value(typeHint);
-		if (!paths.isEmpty()) {
-			iFileCount += addFiles(typeHint, paths);
-			startScan(typeHint);
-		}
+		iFileCount += startScan(qtractorPluginType::Vst2);
 	}
 #endif
 #ifdef CONFIG_VST3
 	// VST3 default path...
 	if (m_typeHint == qtractorPluginType::Any ||
 		m_typeHint == qtractorPluginType::Vst3) {
-		const qtractorPluginType::Hint typeHint
-			= qtractorPluginType::Vst3;
-		const QStringList& paths = m_paths.value(typeHint);
-		if (!paths.isEmpty()) {
-			iFileCount += addFiles(typeHint, paths);
-			startScan(typeHint);
-		}
+		iFileCount += startScan(qtractorPluginType::Vst3);
 	}
 #endif
 #ifdef CONFIG_CLAP
 	// CLAP default path...
 	if (m_typeHint == qtractorPluginType::Any ||
 		m_typeHint == qtractorPluginType::Clap) {
-		const qtractorPluginType::Hint typeHint
-			= qtractorPluginType::Clap;
-		const QStringList& paths = m_paths.value(typeHint);
-		if (!paths.isEmpty()) {
-			iFileCount += addFiles(typeHint, paths);
-			startScan(typeHint);
-		}
+		iFileCount += startScan(qtractorPluginType::Clap);
 	}
 #endif
 #ifdef CONFIG_LV2
 	// LV2 default path...
 	if (m_typeHint == qtractorPluginType::Any ||
 		m_typeHint == qtractorPluginType::Lv2) {
-		const qtractorPluginType::Hint typeHint
-			= qtractorPluginType::Lv2;
-		QStringList& files = m_files[typeHint];
-		files.append(qtractorLv2PluginType::lv2_plugins());
-		iFileCount += files.count();
-		startScan(typeHint);
+		iFileCount += startScan(qtractorPluginType::Lv2);
 	}
 #endif
 
@@ -715,6 +690,14 @@ void qtractorPluginFactory::clearAll ( qtractorPluginType::Hint typeHint )
 int qtractorPluginFactory::addFiles (
 	qtractorPluginType::Hint typeHint, const QStringList& paths )
 {
+#ifdef CONFIG_LV2
+	if (typeHint == qtractorPluginType::Lv2) {
+		QStringList& files = m_files[typeHint];
+		files.append(qtractorLv2PluginType::lv2_plugins());
+		return files.count();
+	}
+#endif
+
 	int iFileCount = 0;
 
 	QStringListIterator path_iter(paths);
@@ -724,6 +707,7 @@ int qtractorPluginFactory::addFiles (
 	return iFileCount;
 }
 
+
 int qtractorPluginFactory::addFiles (
 	qtractorPluginType::Hint typeHint, const QString& sPath )
 {
@@ -743,11 +727,11 @@ int qtractorPluginFactory::addFiles (
 		if (info.isDir() && info.isReadable())
 			iFileCount += addFiles(typeHint, sFilename);
 		else
-		if (QLibrary::isLibrary(sFilename)
+		if (!files.contains(sFilename) && (QLibrary::isLibrary(sFilename)
 		#ifdef CONFIG_CLAP
 			|| (typeHint == qtractorPluginType::Clap && info.suffix() == "clap")
 		#endif
-		) {
+		)) {
 			files.append(sFilename);
 			++iFileCount;
 		}
@@ -1239,6 +1223,13 @@ bool qtractorPluginFactory::Scanner::addTypes (
 }
 
 
+// Cached files accessor.
+QStringList qtractorPluginFactory::Scanner::files (void) const
+{
+	return m_list.keys();
+}
+
+
 // Cache hash result.
 int qtractorPluginFactory::Scanner::dummyPluginHash (void) const
 {
