@@ -53,6 +53,12 @@ public:
 	qtractorPluginType::Hint typeHint() const
 		{ return m_typeHint; }
 
+	// Plugin rescan force flag accessors.
+	void setRescan(bool bRescan)
+		{ m_bRescan = bRescan; }
+	bool isRescan() const
+		{ return m_bRescan; }
+
 	// Executive methods.
 	void scan();
 
@@ -113,7 +119,7 @@ protected:
 	bool writeBlacklist(QFile& file, const QStringList& blacklist) const;
 
 	// Generic plugin-scan factory method.
-	bool startScan(qtractorPluginType::Hint typeHint);
+	int startScan(qtractorPluginType::Hint typeHint);
 
 	// Plugin scan reset method.
 	void reset();
@@ -123,6 +129,9 @@ private:
 	// Instance variables.
 	qtractorPluginType::Hint m_typeHint;
 
+	// Thether the next scan is deeper.
+	bool m_bRescan;
+
 	// Internal plugin-paths.
 	Paths m_paths;
 
@@ -172,6 +181,9 @@ public:
 	// Service methods.
 	bool addTypes(qtractorPluginType::Hint typeHint, const QString& sFilename);
 
+	// Cached files list accessor.
+	QStringList files() const;
+
 	// Cache hash result.
 	int dummyPluginHash() const;
 
