@@ -1,7 +1,7 @@
 // qtractorPluginListView.h
 //
 /****************************************************************************
-   Copyright (C) 2005-2023, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2024, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -91,7 +91,7 @@ class qtractorPluginListView : public QListWidget
 public:
 
 	// Construcctor.
-	qtractorPluginListView(QWidget *pParent = 0);
+	qtractorPluginListView(QWidget *pParent = nullptr);
 	// Destructor.
 	~qtractorPluginListView();
 
