@@ -623,6 +623,13 @@ bool qtractorTrack::open (void)
 	// Ah, at least make new name feedback...
 	updateTrackName();
 
+	// Formerly on mixer track strip update,
+	// but now where it surely belongs, here...
+	//
+	mapControllers();
+
+	applyCurveFile(m_pCurveFile);
+
 	// Done.
 	return (m_pMonitor != nullptr);
 }
@@ -811,6 +818,9 @@ void qtractorTrack::setRecord ( bool bRecord )
 		const unsigned long iFrameTime = m_pSession->frameTimeEx();
 		m_pSession->trackRecord(this, bRecord, iClipStart, iFrameTime);
 	}
+	else
+	if (!bRecord)
+		m_pSession->trackRecord(this, false, 0, 0);
 }
 
 bool qtractorTrack::isRecord (void) const
@@ -1312,6 +1322,13 @@ void qtractorTrack::removeClip ( qtractorClip *pClip )
 	if (m_props.trackType == qtractorTrack::Midi)
 		m_pSession->files()->removeClipItem(qtractorFileList::Midi, pClip);
 
+	if (m_bClipRecordEx && m_pClipRecord == pClip) {
+		m_bClipRecordEx = false;
+		m_pClipRecord = nullptr;
+		m_iClipRecordStart = 0;
+		setRecord(false);
+	}
+
 	pClip->setActive(false);
 
 	m_clips.unlink(pClip);
