@@ -178,8 +178,9 @@ protected:
 	class EventList;
 	class Stream;
 
-	// Plugin instance initializer.
+	// Plugin instance (de)initializer.
 	void initialize();
+	void deinitialize();
 
 	// Internal accessors.
 	EditorFrame *editorFrame() const;
