@@ -81,8 +81,8 @@ AAX_Result AAXWrapper_GUI::GetViewSize (AAX_Point* oEffectViewSize) const
 	int32 width, height;
 	if (params->getWrapper ()->getEditorSize (width, height))
 	{
-		oEffectViewSize->horz = width;
-		oEffectViewSize->vert = height;
+		oEffectViewSize->horz = static_cast<float> (width);
+		oEffectViewSize->vert = static_cast<float> (height);
 	}
 	return AAX_SUCCESS;
 }
