@@ -9,7 +9,7 @@
 //
 //-----------------------------------------------------------------------------
 // LICENSE
-// (c) 2023, Steinberg Media Technologies GmbH, All Rights Reserved
+// (c) 2024, Steinberg Media Technologies GmbH, All Rights Reserved
 //-----------------------------------------------------------------------------
 // Redistribution and use in source and binary forms, with or without modification,
 // are permitted provided that the following conditions are met:
@@ -48,6 +48,7 @@
 #include "AAX_CUnitDisplayDelegateDecorator.h"
 
 #include "../hosting/hostclasses.h"
+#include "pluginterfaces/base/funknownimpl.h"
 #include "pluginterfaces/base/futils.h"
 #include "pluginterfaces/vst/ivstaudioprocessor.h"
 #include "pluginterfaces/vst/ivstchannelcontextinfo.h"
@@ -779,7 +780,7 @@ AAX_Result AAXWrapper_Parameters::NotificationReceived (AAX_CTypeID iNotificatio
 		case AAX_eNotificationEvent_SideChainBeingDisconnected:
 			mWrapper->setSideChainEnable (false);
 			break;
-		//--- The host has changed its latency compensation for this Plug-in instance.
+		//--- The host has changed its latency compensation for this plug-in instance.
 		case AAX_eNotificationEvent_SignalLatencyChanged:
 		{
 			int32_t outSample;
@@ -841,9 +842,8 @@ AAX_Result AAXWrapper_Parameters::NotificationReceived (AAX_CTypeID iNotificatio
 
 			if (mWrapper->mController)
 			{
-				FUnknownPtr<Vst::ChannelContext::IInfoListener> iChannelContextInfoListener (
-				    mWrapper->mController);
-				if (iChannelContextInfoListener)
+				if (auto iChannelContextInfoListener =
+				        U::cast<Vst::ChannelContext::IInfoListener> (mWrapper->mController))
 				{
 					auto list = Vst::HostAttributeList::make ();
 					String string;
